==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AverageDirectionalIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageDirectionalIndexIndicator, _super);
    function AverageDirectionalIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageDirectionalIndexIndicator.prototype.get_yy = function () {
        return new AverageDirectionalIndexIndicatorStrategy();
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.get_zb = function () {
        return AverageDirectionalIndexIndicator.$;
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.zk));
        },
        set: function (a) {
            this.h(AverageDirectionalIndexIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.y4 = function () {
        return this.zj;
    };
    AverageDirectionalIndexIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    AverageDirectionalIndexIndicator.$t = markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.zk = StrategyBasedIndicator.zg(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
}(StrategyBasedIndicator));
export { AverageDirectionalIndexIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/AverageDirectionalIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageDirectionalIndexIndicatorStrategy } from "./AverageDirectionalIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AverageDirectionalIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AverageDirectionalIndexIndicator, _super);
    function AverageDirectionalIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageDirectionalIndexIndicator.prototype.bj = function () {
        return new AverageDirectionalIndexIndicator();
    };
    AverageDirectionalIndexIndicator.prototype.get_abq = function () {
        return new AverageDirectionalIndexIndicatorStrategy();
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.get_ab3 = function () {
        return AverageDirectionalIndexIndicator.$;
    };
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AverageDirectionalIndexIndicator.prototype, "acb", {
        get: function () {
            return typeGetValue(this.c(AverageDirectionalIndexIndicator.acc));
        },
        set: function (a) {
            this.h(AverageDirectionalIndexIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    AverageDirectionalIndexIndicator.prototype.abw = function () {
        return this.acb;
    };
    AverageDirectionalIndexIndicator.prototype.ab5 = function (a) {
        this.acb = a;
    };
    AverageDirectionalIndexIndicator.$t = markType(AverageDirectionalIndexIndicator, 'AverageDirectionalIndexIndicator', StrategyBasedIndicator.$);
    AverageDirectionalIndexIndicator.acc = StrategyBasedIndicator.ab8(14, AverageDirectionalIndexIndicator.$);
    return AverageDirectionalIndexIndicator;
}(StrategyBasedIndicator));
export { AverageDirectionalIndexIndicator };
